class pe_console::console_auth (
  $db_host,
  $db_password,
  $db_port           = undef,
  $db_database       = 'console_auth',
  $db_username       = 'console_auth',
  $db_adapter        = 'mysql',
  $smtp_host         = 'localhost',
  $smtp_port         = 25,
  $smtp_username     = undef,
  $smtp_password     = undef,
  $console_host      = undef,
  $login_username    = undef,
  $login_password    = undef,
  $console_auth_root = '/opt/puppet/share/console-auth',
) {
  include pe_console::common

  class { 'pe_console::console_auth::config':
    smtp_host     => $smtp_host,
    smtp_port     => $smtp_port,
    smtp_username => $smtp_username,
    smtp_password => $smtp_password,
    console_host  => $console_host,
  }

  class { 'pe_console::console_auth::database':
    host       => $db_host,
    password   => $db_password,
    port       => $db_port,
    database   => $db_database,
    username   => $db_username,
    adapter    => $db_adapter,
  }

  exec { 'puppet-console_auth-dbmigrate':
    path        => '/opt/puppet/bin:/usr/bin:/bin',
    cwd         => $console_auth_root,
    command     => 'rake db:migrate',
    refreshonly => true,
    subscribe   => Class['pe_console::console_auth::database'],
  }

  if ($login_username and $login_password) {
    exec { 'puppet-console_auth-login_user':
      path        => '/opt/puppet/bin:/usr/bin:/bin',
      cwd         => $console_auth_root,
      command     => "rake db:create_user USERNAME='${login_username}' PASSWORD='${login_password}' ROLE='Admin'",
      refreshonly => true,
      require     => Exec['puppet-console_auth-dbmigrate'],
      subscribe   => Class['pe_console::console_auth::database'],
    }
  }

}
