# Example config hash to put in hiera
#
# pe_console_backend::db_config_hash:
#   :root_password: 'puppetlabs'
#   :bind_address:  '0.0.0.0'
#
class pe_console::db (
  $console_password,
  $consoleauth_password,
  $inventoryservice_password,
  $db_config_hash            = {},
  $console_database          = 'console',
  $console_username          = 'console',
  $consoleauth_database      = 'console_auth',
  $consoleauth_username      = 'console_auth',
  $inventoryservice_database = 'console_inventory_service',
  $inventoryservice_username = 'console',
  $remove_anonymous_logins   = true,
) {

  class { '::mysql::server':
    enabled     => true,
    config_hash => $db_config_hash,
  }

  Pe_console::Db::Conditional_db_user_grant {
    before => Anchor['pe_console::db::end'],
  }

  pe_console::db::conditional_db_user_grant { 'console':
    database => $console_database,
    username => $console_username,
    password => $console_password,
  }
  pe_console::db::conditional_db_user_grant { 'consoleauth':
    database => $consoleauth_database,
    username => $consoleauth_username,
    password => $consoleauth_password,
  }
  pe_console::db::conditional_db_user_grant { 'inventoryservice':
    database => $inventoryservice_database,
    username => $inventoryservice_username,
    password => $inventoryservice_password,
  }

  # This is a good idea from a security standpoint AND it eliminates the
  # possibility of anonymous accounts preventing legitimate account
  # connections (see http://bit.ly/U7I5Xl, though by reading it you'd think
  # the described problem could never happen).
  if $remove_anonymous_logins {
    exec { 'remove_anonymous_mysql_logins':
      path     => '/usr/bin:/bin:/usr/sbin:/sbin',
      provider => shell,
      command  => 'mysql mysql -BNe "DELETE FROM user WHERE User = \'\'; FLUSH PRIVILEGES;"',
      unless   => 'test `mysql mysql -BNe "SELECT COUNT(*) from user where User=\'\';"` = 0',
    }
  }

  anchor { 'pe_console::db::end': }

}
